pillow: Python Imaging Library
==============================

Description
-----------

Pillow is the "friendly" PIL fork by Alex Clark and Contributors.

The Python Imaging Library (PIL) adds powerful image processing and
graphics capabilities to Python. The library supports many file formats.

License
-------

Standard PIL License


Upstream Contact
----------------

- Author: Alex Clark <aclark@aclark.net>
- https://python-pillow.org/
- Homepage: http://python-imaging.github.io/

Dependencies
------------

-  Python
